/*
 * JBoss, Home of Professional Open Source
 * Copyright XXXX, Red Hat Middleware LLC, and individual contributors as indicated
 * by the @authors tag. All rights reserved.
 * See the copyright.txt in the distribution for a full listing
 * of individual contributors.
 * This copyrighted material is made available to anyone wishing to use,
 * modify, copy, or redistribute it subject to the terms and conditions
 * of the GNU General Public License, v. 2.0.
 * This program is distributed in the hope that it will be useful, but WITHOUT A
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.
 * You should have received a copy of the GNU General Public License,
 * v. 2.0 along with this distribution; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
 * MA 02110-1301, USA.
 */
package org.mobicents.media.server.impl.resource.mediaplayer.mpeg;

import java.io.DataInputStream;
import java.io.IOException;

/**
 * <b>8.1.1.1 Definition</b>
 * <ul>
 * <li>Box Type: �?mdat’</li>
 * <li>Container: File</li>
 * <li>Mandatory: No</li>
 * <li>Quantity: Any number</li>
 * </ul>
 * <p>
 * This box contains the media data. In video tracks, this box would contain video frames. A presentation may contain
 * zero or more Media Data Boxes. The actual media data follows the type field; its structure is described by the
 * metadata (see particularly the {@link SampleTableBox}, subclause 8.5, and the item location box, subclause 8.11.3).
 * </p>
 * <p>
 * In large presentations, it may be desirable to have more data in this box than a 32-bit size would permit. In this
 * case, the large variant of the size field, above in subclause 6.2, is used.
 * </p>
 * <p>
 * There may be any number of these boxes in the file (including zero, if all the media data is in other files). The
 * metadata refers to media data by its absolute offset within the file (see subclause 8.7.5, the Chunk Offset Box); so
 * Media Data Box headers and free space may easily be skipped, and files without any box structure may also be
 * referenced and used.
 * </p>
 * 
 * @author amit bhayani
 * 
 */
public class MediaDataBox extends Box {

	// File Type = mdat
	static byte[] TYPE = new byte[] { AsciiTable.ALPHA_m, AsciiTable.ALPHA_d, AsciiTable.ALPHA_a, AsciiTable.ALPHA_t };
	static String TYPE_S = "mdat";
	static {
		bytetoTypeMap.put(TYPE, TYPE_S);
	}

	private byte[] data;

	public MediaDataBox(long size) {
		super(size, TYPE_S);
	}

	@Override
	protected int load(DataInputStream fin) throws IOException {
		int count = 8;
		int length = (int) this.getSize() - count;
		// data = new byte[length];

		// We are just skiping. The RandomAccessFile should be used for reading byte[]
		count += fin.skip(length);
		// count += fin.read(data, 0, length);
		return count;
	}

}
